@@ -35,6 +35,9 @@
 #'   background filtering is needed, set bounds to some non-numeric value
 #'   (\code{NULL}, \code{FALSE}, \code{"off"}, etc); any non-numeric value is
 #'   interpreted as \code{NULL}.
+#' @param alpha.channel Logical. If available, should alpha channel transparency be
+#'   used to mask background? See \code{\link{removeBackground}} for more
+#'   details.
 #' @param title String for what the title the plot if plotting is on; defaults
 #'   to the image name.
 #' @param a.bounds,b.bounds Numeric ranges for the a (green-red) and b
@@ -85,6 +88,7 @@
 #' @export
 getLabHist <- function(image, bins = 3, sample.size = 10000, 
                        ref.white, from = "sRGB", bin.avg = TRUE, 
+                       alpha.channel = TRUE,
                        as.vec = FALSE, plotting = TRUE,
                        lower=c(0, 0.55, 0), upper=c(0.24, 1, 0.24), 
                        title = "path", a.bounds = c(-128, 127),
@@ -99,7 +103,8 @@ getLabHist <- function(image, bins = 3, sample.size = 10000,
     if (file.exists(image)) {
       image <- loadImage(image, lower = lower, upper = upper, hsv = FALSE, 
                          CIELab = TRUE, sample.size = sample.size,
-                         ref.white = ref.white)
+                         ref.white = ref.white,
+                         alpha.channel = alpha.channel)
     }
   } else if (!is.list(image)) {
     stop("'image' must be either a path to the image",
@@ -142,6 +147,33 @@ getLabHist <- function(image, bins = 3, sample.size = 10000,
     
   }
   
+  # Check if all of the pixels fall within the a/b boundaries
+  a_range_check <- pix$a < a.bounds[1] | pix$a > a.bounds[2]
+  b_range_check <- pix$b < b.bounds[1] | pix$b > b.bounds[2]
+  
+  # if any of them are outside of 0, throw a warning and remove them from pix
+  if ((sum(a_range_check) | sum(b_range_check)) > 0) {
+    
+    # get the actual range
+    ab_range <- round(apply(pix[ , 2:3], 2, range), digits = 2)
+    
+    # Be nice and provide real ranges
+    warning("The specified a and/or b boundaries have removed",
+    " some non-background pixels from the analysis. \nMinimum ",
+    "ranges to include all pixels are:\n",
+    paste0("a: [", ab_range[1, 1], ", ", ab_range[2, 1]), "]\n",
+    paste0("b: [", ab_range[1, 2], ", ", ab_range[2, 2], "]"))
+    
+    # Remove the pixels that were cut off to avoid NA bins
+    # Find pixel indices
+    cutoff_idx <- unique(c(which(a_range_check), 
+                           which(b_range_check)))
+    
+    # Remove those pixels from the total
+    pix <- pix[-cutoff_idx, ]
+    
+  }
+  
   # Bin all the channels
   binnedImage <- data.frame(
     L = cut(pix[, 1], breaks = breaks$L, include.lowest = T, labels = F),
@@ -268,6 +300,9 @@ getLabHist <- function(image, bins = 3, sample.size = 10000,
 #'   background filtering is needed, set bounds to some non-numeric value
 #'   (\code{NULL}, \code{FALSE}, \code{"off"}, etc); any non-numeric value is
 #'   interpreted as \code{NULL}.
+#' @param alpha.channel Logical. If available, should alpha channel transparency be
+#'   used to mask background? See \code{\link{removeBackground}} for more
+#'   details.
 #' @param title String for what the title the plot if plotting is on; defaults
 #'   to the image name.
 #' @param a.bounds,b.bounds Numeric ranges for the a (green-red) and b
@@ -294,14 +329,6 @@ getLabHist <- function(image, bins = 3, sample.size = 10000,
 #' \href{https://en.wikipedia.org/wiki/Standard_illuminant}{standard
 #' illuminants} to choose an appropriate reference for a dataset.
 #' 
-#' The conversion from RGB to a standardized color space (XYZ, Lab, or Luv) is
-#' approximate, non-linear, and relatively time-consuming. Converting a large
-#' number of pixels can be computationally expensive, so
-#' \code{convertColorSpace} will randomly sample a specified number of rows to
-#' reduce the time. The default sample size, 10,000 rows, takes about 1 second to
-#' convert from sRGB to Lab space on an early 2015 Macbook with 8 GB of RAM.
-#' Time scales about linearly with number of rows converted.
-#' 
 #' Unlike RGB or HSV color spaces, the three channels of CIE Lab color space do
 #' not all range between 0 and 1; instead, L (luminance) is always between 0 and
 #' 100, and the a (green-red) and b (blue-yellow) channels generally vary
@@ -322,6 +349,7 @@ getLabHistList <- function(images, bins = 3, sample.size = 10000,
                            ref.white, from = "sRGB", bin.avg = TRUE, 
                            as.vec = FALSE, plotting = FALSE, pausing = TRUE,
                            lower = c(0, 0.55, 0), upper = c(0.24, 1, 0.24),
+                           alpha.channel = TRUE,
                            title = "path", a.bounds = c(-128, 127),
                            b.bounds = c(-128, 127), ...) {
   
@@ -389,6 +417,7 @@ getLabHistList <- function(images, bins = 3, sample.size = 10000,
     end.list[[i]] <- suppressMessages(getLabHist(im.paths[i], bins = bins, 
                                       bin.avg = bin.avg,
                                       lower = lower, upper = upper,
+                                      alpha.channel = alpha.channel,
                                       plotting = plotting, title = title,
                                       ref.white = ref.white, from = from,
                                       a.bounds = a.bounds, b.bounds = b.bounds))
